@@ -19,13 +19,18 @@ impl TokenStream {
     }
 
     /// Push the given sequence of tokens.
-    pub fn tokens<T>(&mut self, span: Span, tt: T)
+    pub fn write<T>(&mut self, span: Span, tt: T)
     where
         T: ToTokens,
     {
         tt.to_tokens(self, span);
     }
 
+    /// Get a checkpoint of the current location in the tree.
+    pub fn checkpoint(&self) -> Checkpoint {
+        Checkpoint(self.inner.len())
+    }
+
     /// Push the given stream as a group.
     pub fn group(&mut self, span: Span, delimiter: Delimiter, Checkpoint(start): Checkpoint) {
         let it = self.inner.drain(start..);
@@ -43,9 +48,4 @@ impl TokenStream {
     pub fn extend(&mut self, mut other: Self) {
         self.inner.append(&mut other.inner);
     }
-
-    /// Get a checkpoint of the current location in the tree.
-    pub fn checkpoint(&self) -> Checkpoint {
-        Checkpoint(self.inner.len())
-    }
 }
